pub(crate) enum UnderlyingSourceType<'a> {
Memory(usize),
Blob(usize),
FetchResponse,
Js(UnderlyingSource<DomTypeHolder>),
Tee(&'a DefaultTeeUnderlyingSource),
Transfer(&'a MessagePort),
Transform(&'a TransformStream, Rc<Promise>),
TeeByte(&'a ByteTeeUnderlyingSource),
}Expand description
https://streams.spec.whatwg.org/#underlying-source-api
The Js variant corresponds to
the JavaScript object representing the underlying source.
The other variants are native sources in Rust.
Variants
Memory(usize)
Facilitate partial integration with sources that are currently read into memory.
Blob(usize)
A blob as underlying source, with a known total size.
FetchResponse
A fetch response as underlying source.
Js(UnderlyingSource<DomTypeHolder>)
A struct representing a JS object as underlying source,
and the actual JS object for use as thisArg in callbacks.
Tee(&'a DefaultTeeUnderlyingSource)
Tee
Transfer(&'a MessagePort)
Transfer, with the port used in some of the algorithms.
Transform(&'a TransformStream, Rc<Promise>)
A struct representing a JS object as underlying source,
and the actual JS object for use as thisArg in callbacks.
This is used for the TransformStream API.
TeeByte(&'a ByteTeeUnderlyingSource)
Tee Byte
Implementations